@@ -85,17 +85,52 @@ public class v3_X_Changes {
 		changes.hardlight(Window.TITLE_COLOR);
 		changeInfos.add(changes);
 
-		changes = new ChangeInfo("", false, null);
+		changes = new ChangeInfo("v3.3.3 & v3.3.2", false, null);
 		changes.hardlight(Window.TITLE_COLOR);
 		changeInfos.add(changes);
 
+		changes.addButton(new ChangeButton(new Image(Assets.Sprites.SPINNER, 144, 0, 16, 16), "v3.3.3",
+				"v3.3.3 is a quick followup patch to fix one serious bug introduced in v3.3.2, sorry for the trouble!\n\n" +
+				"Fixed the following bugs:\n" +
+				"**Caused by v3.3.2:**\n" +
+				"**-** Crashes caused by resurrection via unblessed ankh while holding a skeleton key."));
+
+		changes.addButton( new ChangeButton(new Image(new ImpSprite()), "Quest Tester Area Progress",
+				"Happy New Year Everyone!\n\n" +
+				"I've made some progress over the holidays on the new quest tester area. It's now entirely generated by the game's levelgen system, whereas the previous iteration was mostly hardcoded.\n\n" +
+				"There's still quite a bit I plan to do in future v3.3 patches though."));
+
+		changes.addButton(new ChangeButton(Icons.get(Icons.PREFS), Messages.get(ChangesScene.class, "misc"),
+				"**- Shocking Enchantment** now has a flat 1/3 chance to trigger (instead of (lvl+1)/(lvl+4)), but damage ratio increased to 50% from 40%. Previously shocking effectively scaled based on weapon level twice, which made it disproportionally powerful at high levels and/or with arcana ring.\n\n" +
+				"**- Glyph of Swiftness** now requires a distance of 2 tiles from an enemy, up from 1. This effectively reverts its power to what is was prior to v3.3's change to speed boost logic.\n\n" +
+				"**-** The main target is now prioritized for sniper's mark if a force cube hits multiple enemies\n" +
+				"**-** Remains no longer appear in the vault tester level\n" +
+				"**-** Updated translations and translator credits"));
+
+		changes.addButton(new ChangeButton(new Image(Assets.Sprites.SPINNER, 144, 0, 16, 16), Messages.get(ChangesScene.class, "bugfixes"),
+				"Fixed the following bugs:\n" +
+				"**Caused by v3.3:**\n" +
+				"**-** Monk energy starting at 10 instead of 0 after subclass is chosen\n" +
+				"**-** Game showing a warning about save file errors in more cases than it should\n" +
+				"**-** Rare cases where keys would be discarded when they shouldn't be\n" +
+				"**-** Landmark for distant well rooms not being cleared when the skeleton key is used to open their door\n" +
+				"**-** Various rare crash bugs\n" +
+				"**-** Various minor textual errors\n" +
+				"\n" +
+				"**Existed Prior to v3.3:**\n" +
+				"**-** Crash on launch on old iOS devices with A7 and A8 processors\n" +
+				"**-** Cases where the Steam version could hang on launch on Linux\n" +
+				"**-** Reclaim trap counting as being cast for talents even when it isn't consumed\n" +
+				"**-** Pickaxe being marked as seen before it is given to the player\n" +
+				"**-** Specific cases where ghost ally could regenerate past max HP"));
+
 		changes = new ChangeInfo("v3.3.1", false, null);
 		changes.hardlight(Window.TITLE_COLOR);
 		changeInfos.add(changes);
 
 		changes.addButton(new ChangeButton(new Image(Assets.Sprites.SPINNER, 144, 0, 16, 16), Messages.get(ChangesScene.class, "bugfixes"),
 				"Fixed the following bugs:\n" +
-				"**Caused by v3.3.1:**\n" +
+				"**Caused by v3.3:**\n" +
 				"**-** Skeleton key not triggering on-artifact effects\n" +
 				"**-** Tomahawk bleed damage not scaling with ring of sharpshooting\n" +
 				"**-** Vault tester area being enterable with a lost inventory, causing a softlock\n" +
